#!/bin/bash
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# This script interpolates the erainterim forcing fields from the 1.5*1.5 grid
# to the ORCA1 grid.
# 
# History : Virginie Guemas - Initial version                         - 2012 
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#                                Arguments
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

set -o nounset
set -o errexit

if [ $# = 0 ] ; then
  echo "./interp_eraint.sh YEARB YEARE"
  echo ""
  echo " ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  echo " This script interpolates the erainterim forcing fields from the 1.5*1.5 grid"
  echo " to the ORCA1 grid."
  echo " " 
  echo " History : Virginie Guemas - Initial version                         - 2012 "
  echo " ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  echo "      Arguments: YEARB YEARE (start and end years that have to be processed) "
  echo " ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  exit
fi



year0=$1
yearf=$2

lstvars=( 't2' 'q2' 'precip' 'snow' 'qsw' 'qlw' )
lstmembs=( 1 2 3 4 ) 
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

filescrip=/home/Earth/fmassonn/git-stuff/cfutools/interpolation/scrip_use_extrap
if [ ! -f $filescrip ] ; then
  echo "$filescrip not found, aborting"
  exit
fi
cp $filescrip ./

for ((year=${year0};year<=${yearf};year++)) ; do 

for memb in ${lstmembs[@]} ; do

for var in ${lstvars[@]} ; do

  case $var in
    'u10'|'v10') mid='_fc$'${memb}'_' ;;
    *) mid='_' ;;
  esac

  filenc=${var}${mid}eraint_${year}.nc
  if [ ! -f $filenc ]; then
    echo "$filenc not found, aborting"
    exit
  fi
  
  case $var in 
    'u10'|'v10') ncpdq -O -U ${var}_eraint_${year}.nc ${var}_eraint_${year}.nc ;;
  esac
  case $var in
    't2'|'q2') nstep=1460 ; method='bicubic' ;    
      filewgts='./WEIGHTS/rmp_ERAint_ocean_to_ORCA1t_v3.2_bicubic.nc' ;;
    'precip'|'snow') nstep=12; method='bicubic' ; 
      filewgts='./WEIGHTS/rmp_ERAint_ocean_to_ORCA1t_v3.2_bicubic.nc' ;;
    'qsw'|'qlw') nstep=365; method='bicubic' ;
      filewgts='./WEIGHTS/rmp_ERAint_ocean_to_ORCA1t_v3.2_bicubic.nc' ;;
  esac
  
  if [ ! -f $filewgts ] ; then
    echo "$filewgts not found, abort"
    exit
  fi
  
  cat > scrip_use_in <<EOF
&remap_inputs
    remap_wgt   = '${filewgts}'
    infile      = '${var}_eraint_${year}.nc'
    invertlat   = TRUE 
    var         = '${var}'
    fromregular = TRUE
    outfile     = '${var}_eraint_${year}_orca1.nc'
/
EOF
./scrip_use_extrap

rm -f ${var}_eraint_${year}.nc
ncks -O -v ${var} ${var}_eraint_${year}_orca1.nc ${var}_eraint_${year}_orca1.nc

done

done

done
rm -f scrip_use_in scrip_use_extrap
