#!/bin/bash
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# This script combines and formats the forcing shortwave and longwave 
# radiation fields. output_step12_0h.nc and output_step12_12h.nc as 
#
# described in README should be in the working directory 
#
# History : Virginie Guemas - Initial version                         - 2012 
#           Francois Massonnet - cleaning up                          - 2015
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#                                Arguments
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
set -o nounset
set -o errexit

if [ $# = 0 ] ; then
  echo "./prep_era_int_qsw_qlw_forcings.sh YEAR                                     "
  echo "                                                                            " 
  echo "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~" 
  echo "This script combines and formats the forcing shortwave and longwave         "
  echo "radiation fields. output_step12_0h.nc and output_step12_12h.nc as           "
  echo "described in README should be in the working directory                      "
  echo "                                                                            "
  echo "History : Virginie Guemas - Initial version                         - 2012  "
  echo "          Francois Massonnet - Cleaning up                          - 2015  "
  echo "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  echo "                 Arguments: the year that has to be processed               "
  echo "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  exit
fi

year=$1

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
echo "1/5. Conversion to double..."
ncap2 -O -s "ssrd=double(ssrd)" output_step12_12h.nc output_step12_12h.nc
ncap2 -O -s "strd=double(strd)" output_step12_12h.nc output_step12_12h.nc
ncap2 -O -s "ssrd=double(ssrd)" output_step12_0h.nc output_step12_0h.nc
ncap2 -O -s "strd=double(strd)" output_step12_0h.nc output_step12_0h.nc

echo "2/5. Scale factor and offset adjustment..."
ncatted -O -a add_offset,ssrd,d,d, output_step12_0h.nc output_step12_0h.nc
ncatted -O -a add_offset,strd,d,d, output_step12_0h.nc output_step12_0h.nc
ncatted -O -a scale_factor,strd,d,d, output_step12_0h.nc output_step12_0h.nc
ncatted -O -a scale_factor,ssrd,d,d, output_step12_0h.nc output_step12_0h.nc
ncatted -O -a add_offset,ssrd,d,d, output_step12_12h.nc output_step12_12h.nc
ncatted -O -a add_offset,strd,d,d, output_step12_12h.nc output_step12_12h.nc
ncatted -O -a scale_factor,strd,d,d, output_step12_12h.nc output_step12_12h.nc
ncatted -O -a scale_factor,ssrd,d,d, output_step12_12h.nc output_step12_12h.nc

echo "3/5. Cumulating energy over a day (J/m2) and averaging into W/m2..." 
cdo add output_step12_12h.nc output_step12_0h.nc output_ssrd_strd_int.nc
cdo divc,86400 output_ssrd_strd_int.nc  output_ssrd_strd.nc
ncks -v ssrd output_ssrd_strd.nc qsw_eraint.nc
ncrename -v ssrd,qsw qsw_eraint.nc
ncks -v strd output_ssrd_strd.nc qlw_eraint.nc
ncrename -v strd,qlw qlw_eraint.nc
cdo shifttime,-12h qlw_eraint.nc qlw_eraint_${year}.nc
cdo shifttime,-12h qsw_eraint.nc qsw_eraint_${year}.nc

echo "4/5. Cleaning..."
rm -f output_step12_0h.nc output_step12_12h.nc output_ssrd_strd_int.nc output_ssrd_strd.nc qsw_eraint.nc qlw_eraint.nc


echo "5/5. Finished with success! Files qlw_eraint_${year}.nc and qsw_eraint_${year}.nc are created. Check them."
