#!/bin/bash
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# This script combines and formates the temperature, dew point and pressure  
# fields to build the forcing temperature and humidity fields afterwards. 
# output_step12_0h.nc and output_step12_12h.nc as described in README should 
# be in the working directory 
#
# History : Virginie Guemas - Initial version                         - 2012 
#           Francois Massonnet - Cleaning up                          - 2015
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#                                Arguments
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
set -o nounset
set -o errexit

if [ $# = 0 ] ; then
  echo "./prep_era_t2_q2_forcings.sh YEAR                                           "
  echo "                                                                            " 
  echo "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~" 
  echo "This script combines and formats the forcing t2m and q2m                    "
  echo "output_step0.nc                                                             "
  echo "described in README should be in the working directory                      "
  echo "                                                                            "
  echo "History : Virginie Guemas - Initial version                         - 2012  "
  echo "          Francois Massonnet - Cleaning up                          - 2015  "
  echo "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  echo "                 Arguments: the year that has to be processed               "
  echo "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  exit
fi

year=$1

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
echo "1/5. Conversion to double..."
ncap2 -O -s "d2m=double(d2m)" output_step0.nc output_step0.nc
ncap2 -O -s "t2m=double(t2m)" output_step0.nc output_step0.nc
ncap2 -O -s "sp=double(sp)"   output_step0.nc output_step0.nc

echo "2/5. Scale factor and offset adjustment..."
ncatted -O -a add_offset,d2m,d,d, output_step0.nc output_step0.nc
ncatted -O -a add_offset,t2m,d,d, output_step0.nc output_step0.nc
ncatted -O -a add_offset,sp,d,d, output_step0.nc output_step0.nc
ncatted -O -a scale_factor,d2m,d,d, output_step0.nc output_step0.nc
ncatted -O -a scale_factor,t2m,d,d, output_step0.nc output_step0.nc
ncatted -O -a scale_factor,sp,d,d, output_step0.nc output_step0.nc

echo "3/5 Dumping and renaming..."
ncks     -O -v t2m output_step0.nc t2m_eraint_${year}.nc
ncrename -O -v t2m,t2 t2m_eraint_${year}.nc t2_eraint_${year}.nc
ncks     -O -v d2m output_step0.nc d2_eraint_${year}.nc
ncks     -O -v sp output_step0.nc sp_eraint_${year}.nc

echo "4/5 Cleaning"
rm -f output_step0.nc t2m_eraint_${year}.nc 

echo "5/5 Finished with success! Files t2_eraint_${year}.nc, d2_eraint_${year}.nc and sp_eraint_${year}.nc are created. Check them." 
