set -evx
set -o nounset
set -o errexit
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# This script interpolates and rotates the 10m zonal and meridional wind
# perturbations.
#
# History : Virginie Guemas - Initial version                         - 2012 
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#                                Arguments
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
module load netCDF-Fortran/4.2-foss-2015a

if [ $# = 0 ] ; then
  echo "./rotate_perturb.sh YEAR"
  echo " ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  echo " This script interpolates and rotates the 10m zonal and meridional wind"
  echo " perturbations."
  echo ""
  echo " History : Virginie Guemas - Initial version                         - 2012 "
  echo " ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
  echo "                      Arguments: year that has to be processed"
  echo "" 
fi


year=$1                 # Year for which to interpolate and rotate
dir='perturb1_era-dfs_mon'  # Directory from where to take the perturbations

lstmbs=( 1 2 3 4 )

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

remap_wgt_file="../WEIGHTS/rmp_ERAint_to_ORCA1t_unmasked_bicubic.nc"
if [ ! -f $remap_wgt_file ] ; then
  echo "remap_wgt_file not found, abort"
  exit
fi



for memb in ${lstmbs[@]} ; do

cat > scrip_use_in <<EOF
&remap_inputs
    remap_wgt   = '$remap_wgt_file'
    infile      = '${dir}/u10_fc${memb}_${year}.nc'
    invertlat   = TRUE
    var         = 'u10'
    fromregular = TRUE
    outfile     = '${dir}/u10_fc${memb}_eraint_${year}_orca1t_unrotated.nc'
/
EOF
scrip_use_file="/home/Earth/fmassonn/git-stuff/cfutools/interpolation/scrip_use"
if [ ! -f $scrip_use_file ] ; then
  echo "$scrip_use_file not found, abort"
  exit
fi
cp $scrip_use_file scrip_use
./scrip_use

cat > scrip_use_in <<EOF
&remap_inputs
    remap_wgt   = '$remap_wgt_file' 
    infile      = '${dir}/v10_fc${memb}_${year}.nc'
    invertlat   = TRUE
    var         = 'v10'
    fromregular = TRUE
    outfile     = '${dir}/v10_fc${memb}_eraint_${year}_orca1t_unrotated.nc'
/
EOF
./scrip_use


meshmaskfile='/esnas/autosubmit/con_files/mesh_mask_nemo.N3.2_O1L42.nc'
if [ ! -f $meshmaskfile ] ; then
  echo "$meshmaskfile not found, abort"
  exit
fi

cat > namelist_rotateUVorca <<EOF
&nam_rotUV
  Ufilein   =  '${dir}/u10_fc${memb}_eraint_${year}_orca1t_unrotated.nc'
  Uvarin    =  'u10'
  Vfilein   =  '${dir}/v10_fc${memb}_eraint_${year}_orca1t_unrotated.nc'
  Vvarin    =  'v10'
  meshmask  =  '$meshmaskfile'
  Ufileout   =  '${dir}/u10_fc${memb}_eraint_${year}_orca1t.nc'
  Vfileout   =  '${dir}/v10_fc${memb}_eraint_${year}_orca1t.nc'
/
EOF

filerotate='../WEIGHTS/rotateUVorca_orca1'
if [ ! -f $filerotate ] ; then
  echo "$filerotate not found, abort"
  exit
fi
cp $filerotate rotateUVorca
./rotateUVorca

rm -f ${dir}/u10_fc${memb}_eraint_${year}_orca1t_unrotated.nc ${dir}/v10_fc${memb}_eraint_${year}_orca1t_unrotated.nc

done
rm -f scrip_use scrip_use_in rotateUVorca namelist_rotateUVorca
